@@ -624,71 +624,6 @@ g_warning("debug: Box_Data::get_field()");
 }
 */
 
-/*
-Glib::ustring Box_Data::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause)
-{
-  Glib::ustring result;
-
-  Document_Glom* document = get_document();
-
-  Glib::ustring sql_part_fields;
-
-  typedef std::list<Relationship> type_list_relationships;
-  type_list_relationships list_relationships;
-
-  for(type_vecLayoutFields::const_iterator iter =  fieldsToGet.begin(); iter != fieldsToGet.end(); ++iter)
-  {
-    if(iter != fieldsToGet.begin())
-      sql_part_fields += ", ";
-
-
-    if(!iter->get_has_relationship_name())
-    {
-      sql_part_fields += ( table_name + "." );
-    }
-    else
-    {
-      Glib::ustring relationship_name = iter->get_relationship_name();
-      Relationship relationship;
-      bool test = document->get_relationship(table_name, relationship_name, relationship);
-      if(test)
-      {
-        const Glib::ustring field_table_name = relationship->get_to_table();
-        sql_part_fields += ( field_table_name + "." );
-
-        //Add the relationship to the list:
-        type_list_relationships::const_iterator iterFind = std::find_if(list_relationships.begin(), list_relationships.end(), predicate_FieldHasName<Relationship>( relationship_name ) );
-        if(iterFind == list_relationships.end()) //If the table is not yet in the list:
-          list_relationships.push_back(relationship);
-      }
-    }
-
-    sql_part_fields += iter->get_name();
-  }
-
-  result =  "SELECT " + sql_part_fields +
-    " FROM \"" + table_name + "\"";
-
-  //LEFT OUTER JOIN will get the field values from the other tables, and give us our fields for this table even if there is no corresponding value in the other table.
-  Glib::ustring sql_part_leftouterjoin; 
-  for(type_list_relationships::const_iterator iter = list_relationships.begin(); iter != list_relationships.end(); ++iter)
-  {
-    const Relationship& relationship = *iter;
-    sql_part_leftouterjoin += " LEFT OUTER JOIN " + relationship->get_to_table() +
-      " ON (" + relationship->get_from_table() + "." + relationship->get_from_field() + " = " +
-      relationship->get_to_table() + "." + relationship->get_to_field() +
-      ")";
-  }
-
-  result += sql_part_leftouterjoin;
-
-  if(!where_clause.empty())
-    result += " WHERE " + where_clause;
-
-  return result;
-}
-*/
-
 bool Box_Data::get_related_record_exists(const sharedptr<const Relationship>& relationship, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value)
 {
   bool result = false;
@@ -847,5 +782,15 @@ bool Box_Data::confirm_delete_record()
   return (response == Gtk::RESPONSE_OK);
 }
 
-} //namespace Glom
+void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value)
+{
+  const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, get_field_primary_key(), primary_key_value);
 
+ //We need the connection when we run the script, so that the script may use it.
+ sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
+
+  glom_execute_python_function_implementation(layout_item->get_script(), field_values, //TODO: Maybe use the field's type here.
+    get_document(), get_table_name(), sharedconnection->get_gda_connection());
+}
+
+} //namespace Glom
